@@ -6,13 +6,15 @@ from django.conf.global_settings import *
 # LDP              #
 ####################
 
-LDP_RDF_CONTEXT = 'https://cdn.happy-dev.fr/owl/hdcontext.jsonld'
+LDP_RDF_CONTEXT = 'https://cdn.startinblox.com/owl/context.jsonld'
 
 MAX_ACTIVITY_RESCHEDULES = 3
 DEFAULT_BACKOFF_FACTOR = 1
-DEFAULT_ACTIVITY_DELAY = 3
+DEFAULT_ACTIVITY_DELAY = 0.2
 DEFAULT_REQUEST_TIMEOUT = 10
 
+LDP_INCLUDE_INNER_PERMS = False
+
 ####################
 # CORE             #
 ####################
@@ -109,7 +111,6 @@ WSGI_APPLICATION = 'server.wsgi.application'
 # middleware will be applied in the order given, and in the response
 # phase the middleware will be applied in reverse order.
 MIDDLEWARE = [
-    'django_cookies_samesite.middleware.CookiesSameSite',
     'django.middleware.security.SecurityMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.common.CommonMiddleware',
@@ -126,7 +127,8 @@ MIDDLEWARE = [
 # REST FRAMEWORK #
 ##################
 REST_FRAMEWORK = {
-    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema'
+    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
+    'DEFAULT_PAGINATION_CLASS': 'djangoldp.pagination.LDPPagination'
 }
 
 ###################
@@ -155,9 +157,12 @@ DCS_SESSION_COOKIE_SAMESITE = 'none'
 
 AUTHENTICATION_BACKENDS = ['django.contrib.auth.backends.ModelBackend', 'guardian.backends.ObjectPermissionBackend']
 
-OIDC_ACCESS_CONTROL_ALLOW_HEADERS = 'Content-Type, if-match, accept, authorization, DPoP'
+OIDC_ACCESS_CONTROL_ALLOW_HEADERS = 'Content-Type, if-match, accept, authorization, DPoP, cache-control, pragma, prefer'
 
 # The minimum number of seconds a password reset link is valid for
 PASSWORD_RESET_TIMEOUT = 60 * 60 * 24 * 3
 
 DISABLE_LOCAL_OBJECT_FILTER = False
+
+GUARDIAN_AUTO_PREFETCH = True
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
