@@ -1,6 +1,7 @@
 from django.conf import settings
-from django.utils.http import is_safe_url
+from django.utils.http import url_has_allowed_host_and_scheme
 from django.shortcuts import redirect
+from djangoldp.models import Model
 
 
 class AllowOnlySiteUrl:
@@ -9,7 +10,7 @@ class AllowOnlySiteUrl:
 
     def __call__(self, request):
         response = self.get_response(request)
-        if(is_safe_url(request.get_raw_uri(), allowed_hosts=settings.SITE_URL) or response.status_code != 200):
+        if(url_has_allowed_host_and_scheme(request.get_raw_uri(), allowed_hosts=settings.SITE_URL) or response.status_code != 200):
             return response
         else:
             return redirect('{}{}'.format(settings.SITE_URL, request.path), permanent=True)
@@ -23,12 +24,12 @@ class AllowRequestedCORSMiddleware:
     def __call__(self, request):
         response = self.get_response(request)
 
-        response["Access-Control-Allow-Origin"] = request.META.get('HTTP_ORIGIN')
+        response["Access-Control-Allow-Origin"] = request.headers.get('origin')
         response["Access-Control-Allow-Methods"] = "GET,POST,PUT,PATCH,DELETE,OPTIONS,HEAD"
         response["Access-Control-Allow-Headers"] = \
             getattr(settings, 'OIDC_ACCESS_CONTROL_ALLOW_HEADERS',
-                    "authorization, Content-Type, if-match, accept, DPoP")
+                    "authorization, Content-Type, if-match, accept, DPoP, cache-control, prefer")
         response["Access-Control-Expose-Headers"] = "Location, User"
         response["Access-Control-Allow-Credentials"] = 'true'
 
-        return response
+        return response
\ No newline at end of file
