@@ -18,18 +18,8 @@ class TestAutoAuthor(APITestCase):
 
     def test_save_with_anonymous_user(self):
         post = {
-            '@graph': [{'http://happy-dev.fr/owl/#content': "post content"}]}
+            '@graph': [{'https://cdn.startinblox.com/owl#content': "post content"}]}
 
         response = self.client.post('/posts/', data=json.dumps(post), content_type='application/ld+json')
         self.assertEqual(response.status_code, 201)
-        self.assertEquals(response.data['content'], "post content")
-
-    def test_auto_author_field(self):
-        self.client.force_authenticate(user=self.user)
-        post = {
-            '@graph': [{'http://happy-dev.fr/owl/#content': "post content"}]}
-
-        response = self.client.post('/posts/', data=json.dumps(post), content_type='application/ld+json')
-        self.assertEqual(response.status_code, 201)
-        self.assertEquals(response.data['content'], "post content")
-        self.assertIsNotNone(response.data['author'])
+        self.assertEquals(response.data['content'], "post content")
\ No newline at end of file
