@@ -9,10 +9,8 @@ from djangoldp.related import get_prefetch_fields
 
 class LDPViewSet(APITestCase):
 
-    user_serializer_fields = ['@id', 'username', 'first_name', 'last_name', 'email', 'userprofile', 'conversation_set',
-                              'circle_set', 'projects']
-    user_expected_fields = {'userprofile', 'conversation_set', 'circle_set', 'projects', 'circle_set__owner',
-                            'conversation_set__author_user', 'conversation_set__peer_user', 'circle_set__space'}
+    user_serializer_fields = ['@id', 'username', 'first_name', 'last_name', 'email', 'userprofile', 'conversation_set', 'projects']
+    user_expected_fields = {'userprofile', 'conversation_set', 'projects', 'conversation_set__author_user', 'conversation_set__peer_user'}
     project_serializer_fields = ['@id', 'description', 'members']
     project_expected_fields = {'members', 'members__userprofile'}
 
@@ -40,8 +38,8 @@ class LDPViewSet(APITestCase):
     def test_get_prefetch_fields_circle(self):
         model = Circle
         depth = 0
-        serializer_fields = ['@id', 'name', 'description', 'owner', 'members', 'team']
-        expected_fields = {'owner', 'members', 'team', 'members__user', 'members__circle', 'team__userprofile', 'space'}
+        serializer_fields = ['@id', 'name', 'description', 'owner', 'members']
+        expected_fields = {'owner', 'members', 'admins', 'space'}
         serializer = self._get_serializer(model, depth, serializer_fields)
         result = get_prefetch_fields(model, serializer, depth)
         self.assertEqual(expected_fields, result)
@@ -77,11 +75,12 @@ class LDPViewSet(APITestCase):
         response = self.client.get('/circles/', HTTP_ACCEPT_MODEL_FIELDS=fields_shape)
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         response_data_keys = response.data['ldp:contains'][0].keys()
-        self.assertEqual(len(response_data_keys), 4)
+        self.assertIn(len(response_data_keys), (3,4))
         self.assertIn('@id', response_data_keys)
         self.assertIn('name', response_data_keys)
         self.assertIn('@type', response_data_keys)
-        self.assertIn('permissions', response_data_keys)
+        if len(response_data_keys)>3:
+            self.assertIn('@context', response_data_keys)
 
     def test_search_fields_basic(self):
         self.setUpLoggedInUser()
