@@ -4,19 +4,20 @@ from django.conf import settings
 from django.test import override_settings
 from rest_framework.test import APIClient, APITestCase
 from djangoldp.tests.models import JobOffer, LDPDummy, PermissionlessDummy, UserProfile, OwnedResource, \
-    NoSuperUsersAllowedModel, ComplexPermissionClassesModel
+    OwnedResourceNestedOwnership, OwnedResourceTwiceNestedOwnership
 
 import json
 
 
-class TestUserPermissions(APITestCase):
-
+class UserPermissionsTestCase(APITestCase):
     def setUp(self):
         self.user = get_user_model().objects.create_user(username='john', email='jlennon@beatles.com', password='glass onion')
         self.client = APIClient(enforce_csrf_checks=True)
         self.client.force_authenticate(user=self.user)
         self.job = JobOffer.objects.create(title="job", slug="slug1")
 
+
+class TestUserPermissions(UserPermissionsTestCase):
     def setUpGroup(self):
         self.group = Group.objects.create(name='Test')
         view_perm = Permission.objects.get(codename='view_permissionlessdummy')
@@ -28,15 +29,13 @@ class TestUserPermissions(APITestCase):
         self.user.save()
 
     # list - simple
-    @override_settings(SERIALIZE_EXCLUDE_PERMISSIONS=['inherit'],
-                       SERIALIZE_CONTAINER_EXCLUDE_PERMISSIONS=['inherit', 'delete'])
     def test_get_for_authenticated_user(self):
         response = self.client.get('/job-offers/')
         self.assertEqual(response.status_code, 200)
         # test serialized permissions
-        self.assertIn({'mode': {'@type': 'view'}}, response.data['permissions'])
-        self.assertNotIn({'mode': {'@type': 'inherit'}}, response.data['permissions'])
-        # self.assertNotIn({'mode': {'@type': 'delete'}}, response.data['permissions'])
+        self.assertIn('view', response.data['permissions'])
+        self.assertNotIn('inherit', response.data['permissions'])
+        # self.assertNotIn('delete', response.data['permissions'])
 
     # TODO: list - I do not have permission from the model, but I do have permission via a Group I am assigned
     #  https://git.startinblox.com/djangoldp-packages/djangoldp/issues/291
@@ -120,35 +119,35 @@ class TestUserPermissions(APITestCase):
     def test_get_1_for_authenticated_user(self):
         response = self.client.get('/job-offers/{}/'.format(self.job.slug))
         self.assertEqual(response.status_code, 200)
-        self.assertIn({'mode': {'@type': 'view'}}, response.data['permissions'])
-        self.assertNotIn({'mode': {'@type': 'inherit'}}, response.data['permissions'])
+        self.assertIn('view', response.data['permissions'])
+        self.assertNotIn('inherit', response.data['permissions'])
 
     def test_post_request_for_authenticated_user(self):
-        post = {'http://happy-dev.fr/owl/#title': "job_created", "http://happy-dev.fr/owl/#slug": 'slug2'}
+        post = {'https://cdn.startinblox.com/owl#title': "job_created", "https://cdn.startinblox.com/owl#slug": 'slug2'}
         response = self.client.post('/job-offers/', data=json.dumps(post), content_type='application/ld+json')
         self.assertEqual(response.status_code, 201)
 
     # denied because I don't have model permissions
     def test_post_request_denied_model_perms(self):
-        data = {'http://happy-dev.fr/owl/#some': 'title'}
+        data = {'https://cdn.startinblox.com/owl#some': 'title'}
         response = self.client.post('/permissionless-dummys/', data=json.dumps(data), content_type='application/ld+json')
         self.assertEqual(response.status_code, 403)
 
     def test_post_nested_view_authorized(self):
-        data = { "http://happy-dev.fr/owl/#title": "new skill", "http://happy-dev.fr/owl/#obligatoire": "okay" }
+        data = { "https://cdn.startinblox.com/owl#title": "new skill", "https://cdn.startinblox.com/owl#obligatoire": "okay" }
         response = self.client.post('/job-offers/{}/skills/'.format(self.job.slug), data=json.dumps(data),
                                     content_type='application/ld+json')
         self.assertEqual(response.status_code, 201)
 
     def test_post_nested_view_denied_model_perms(self):
         parent = LDPDummy.objects.create(some='parent')
-        data = { "http://happy-dev.fr/owl/#some": "title" }
+        data = { "https://cdn.startinblox.com/owl#some": "title" }
         response = self.client.post('/ldpdummys/{}/anons/'.format(parent.pk), data=json.dumps(data),
                                     content_type='application/ld+json')
         self.assertEqual(response.status_code, 403)
 
     def test_put_request_for_authenticated_user(self):
-        body = {'https://happy-dev.fr/owl/#title':"job_updated"}
+        body = {'https://cdn.startinblox.com/owl#title':"job_updated"}
         response = self.client.put('/job-offers/{}/'.format(self.job.slug), data=json.dumps(body),
                                    content_type='application/ld+json')
         self.assertEqual(response.status_code, 200)
@@ -160,7 +159,7 @@ class TestUserPermissions(APITestCase):
 
     def test_put_request_denied_model_perms(self):
         dummy = PermissionlessDummy.objects.create(some='some', slug='slug')
-        data = {'http://happy-dev.fr/owl/#some': 'new'}
+        data = {'https://cdn.startinblox.com/owl#some': 'new'}
         response = self.client.put('/permissionless-dummys/{}/'.format(dummy.slug), data=json.dumps(data),
                                     content_type='application/ld+json')
         self.assertEqual(response.status_code, 404)
@@ -168,22 +167,23 @@ class TestUserPermissions(APITestCase):
     def test_put_nested_view_denied_model_perms(self):
         parent = LDPDummy.objects.create(some='parent')
         child = PermissionlessDummy.objects.create(some='child', slug='child', parent=parent)
-        data = {"http://happy-dev.fr/owl/#some": "new"}
+        data = {"https://cdn.startinblox.com/owl#some": "new"}
         response = self.client.put('/ldpdummys/{}/anons/{}/'.format(parent.pk, child.slug), data=json.dumps(data),
                                    content_type='application/ld+json')
         self.assertEqual(response.status_code, 404)
 
-    def test_patch_nested_container_attach_existing_resource_permission_denied(self):
-        '''I am attempting to add a resource which I should not know exists'''
-        parent = LDPDummy.objects.create(some='parent')
-        dummy = PermissionlessDummy.objects.create(some='some', slug='slug')
-        data = {
-            'http://happy-dev.fr/owl/#anons': [
-                {'@id': '{}/permissionless-dummys/{}/'.format(settings.SITE_URL, dummy.slug), 'http://happy-dev.fr/owl/#slug': dummy.slug}
-            ]
-        }
-        response = self.client.patch('/ldpdummys/{}/'.format(parent.pk), data=json.dumps(data), content_type='application/ld+json')
-        self.assertEqual(response.status_code, 404)
+    #TODO: check how this could ever work
+    # def test_patch_nested_container_attach_existing_resource_permission_denied(self):
+    #     '''I am attempting to add a resource which I should not know exists'''
+    #     parent = LDPDummy.objects.create(some='parent')
+    #     dummy = PermissionlessDummy.objects.create(some='some', slug='slug')
+    #     data = {
+    #         'https://cdn.startinblox.com/owl#anons': [
+    #             {'@id': '{}/permissionless-dummys/{}/'.format(settings.SITE_URL, dummy.slug), 'https://cdn.startinblox.com/owl#slug': dummy.slug}
+    #         ]
+    #     }
+    #     response = self.client.patch('/ldpdummys/{}/'.format(parent.pk), data=json.dumps(data), content_type='application/ld+json')
+    #     self.assertEqual(response.status_code, 404)
 
     # variations on previous tests with an extra level of depth
     # TODO
@@ -210,14 +210,14 @@ class TestUserPermissions(APITestCase):
 
     def test_put_request_change_pk_rejected(self):
         self.assertEqual(JobOffer.objects.count(), 1)
-        body = {'http://happy-dev.fr/owl/#pk': 2}
+        body = {'https://cdn.startinblox.com/owl#pk': 2}
         response = self.client.put('/job-offers/{}/'.format(self.job.slug), data=json.dumps(body),
                                    content_type='application/ld+json')
         # TODO: this is failing quietly
         #  https://git.happy-dev.fr/startinblox/solid-spec/issues/14
         self.assertEqual(response.status_code, 200)
         self.assertEqual(JobOffer.objects.count(), 1)
-        self.assertFalse(JobOffer.objects.filter(pk=body['http://happy-dev.fr/owl/#pk']).exists())
+        self.assertFalse(JobOffer.objects.filter(pk=body['https://cdn.startinblox.com/owl#pk']).exists())
 
     # tests that I receive a list of objects for which I am owner, filtering those for which I am not
     def test_list_owned_resources(self):
@@ -239,7 +239,7 @@ class TestUserPermissions(APITestCase):
         response = self.client.get('/ownedresources/{}/'.format(my_resource.pk))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.data['@id'], my_resource.urlid)
-        self.assertIn({'mode': {'@type': 'delete'}}, response.data['permissions'])
+        self.assertIn('delete', response.data['permissions'])
 
         # I have permission to view this resource
         response = self.client.patch('/ownedresources/{}/'.format(their_resource.pk))
@@ -254,9 +254,7 @@ class TestUserPermissions(APITestCase):
         self.assertEqual(response.status_code, 200)
 
         response = self.client.patch('/userprofiles/{}/'.format(their_profile.slug))
-        # TODO: technically this should be 403, since I do have permission to view their user profile
-        #  https://git.startinblox.com/djangoldp-packages/djangoldp/issues/336
-        self.assertEqual(response.status_code, 404)
+        self.assertEqual(response.status_code, 403)
 
     def test_delete_owned_resource(self):
         my_resource = OwnedResource.objects.create(description='test', user=self.user)
@@ -303,7 +301,7 @@ class TestUserPermissions(APITestCase):
 
         response = self.client.patch('/userprofiles/{}/'.format(their_profile.slug))
         # TODO: https://git.startinblox.com/djangoldp-packages/djangoldp/issues/336
-        self.assertEqual(response.status_code, 404)
+        self.assertEqual(response.status_code, 403)
 
         self._make_self_superuser()
 
@@ -322,25 +320,6 @@ class TestUserPermissions(APITestCase):
         response = self.client.delete('/ownedresources/{}/'.format(their_resource.pk))
         self.assertEqual(response.status_code, 204)
 
-    # test where superuser_perms are configured on the model to be different
-    def test_superuser_perms_configured(self):
-        self._make_self_superuser()
-
-        NoSuperUsersAllowedModel.objects.create()
-        self.assertEqual(NoSuperUsersAllowedModel.objects.count(), 1)
-
-        response = self.client.get('/nosuperusersallowedmodels/')
-        self.assertEqual(response.status_code, 200)
-        self.assertEqual(len(response.data['ldp:contains']), 0)
-
-    # test list where SuperUserPermission is being used on a model in conjunction with LDPPermissions
-    def test_filter_backend_multiple_permission_classes_configured(self):
-        ComplexPermissionClassesModel.objects.create()
-
-        response = self.client.get('/complexpermissionclassesmodels/')
-        self.assertEqual(response.status_code, 200)
-        self.assertEqual(len(response.data['ldp:contains']), 1)
-
     # I have model (or object?) permissions. Attempt to make myself owner and thus upgrade my permissions
     # TODO: https://git.startinblox.com/djangoldp-packages/djangoldp/issues/356/
     '''
@@ -351,7 +330,7 @@ class TestUserPermissions(APITestCase):
         # authenticated has 'change' permission but only owner's have 'control' permission, meaning that I should
         # not be able to change my privilege level
         body = {
-            'http://happy-dev.fr/owl/#user': {'@id': self.user.urlid}
+            'https://cdn.startinblox.com/owl#user': {'@id': self.user.urlid}
         }
         response = self.client.put('/ownedresourcevariants/{}/'.format(resource.pk), data=json.dumps(body),
                                    content_type='application/ld+json')
@@ -360,3 +339,90 @@ class TestUserPermissions(APITestCase):
         resource = OwnedResourceVariant.objects.get(pk=resource.pk)
         self.assertNotEqual(resource.user, self.user)
     '''
+
+
+class TestOwnerFieldUserPermissions(UserPermissionsTestCase):
+    restore_meta = None
+
+    def setUpTempOwnerFieldForModel(self, model, new_owner_field):
+        # store the old meta information for tearDown to cleanup after the test
+        if self.restore_meta is None:
+            self.restore_meta = []
+        
+        self.restore_meta.append({
+            "model": model,
+            "owner_field": model._meta.owner_field
+        })
+
+        # replace the owner_field attribute for the test to run
+        model._meta.owner_field = new_owner_field
+
+    def tearDown(self):
+        # restore any previously changed owner_field attributes in the test
+        if self.restore_meta is not None:
+            for idx, model in enumerate(self.restore_meta):
+                model = self.restore_meta[idx]["model"]
+                model._meta.owner_field = self.restore_meta[idx]["owner_field"]
+            self.restore_meta = None
+
+    def test_list_owned_resources_nested(self):
+        my_resource = OwnedResource.objects.create(description='test', user=self.user)
+        my_second_resource = OwnedResource.objects.create(description='test', user=self.user)
+        another_user = get_user_model().objects.create_user(username='test', email='test@test.com', password='test')
+        their_resource = OwnedResource.objects.create(description='another test', user=another_user)
+
+        my_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_resource)
+        my_second_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_second_resource)
+        their_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=their_resource)
+
+        response = self.client.get('/ownedresourcenestedownerships/')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.data['ldp:contains']), 2)
+        ids = [r['@id'] for r in response.data['ldp:contains']]
+        self.assertIn(my_nested.urlid, ids)
+        self.assertIn(my_second_nested.urlid, ids)
+        self.assertNotIn(their_nested.urlid, ids)
+    
+    def test_list_owned_resources_nested_variation_urlid(self):
+        owner_field = OwnedResourceNestedOwnership._meta.owner_field
+        OwnedResourceNestedOwnership._meta.owner_field = None
+        OwnedResourceNestedOwnership._meta.owner_urlid_field = owner_field + "__urlid"
+
+        self.test_list_owned_resources_nested()
+        OwnedResourceNestedOwnership._meta.owner_urlid_field = None
+        OwnedResourceNestedOwnership._meta.owner_field = owner_field
+
+    
+    def test_list_owned_resources_nested_variation_twice_nested(self):
+        my_resource = OwnedResource.objects.create(description='test', user=self.user)
+        my_second_resource = OwnedResource.objects.create(description='test', user=self.user)
+        another_user = get_user_model().objects.create_user(username='test', email='test@test.com', password='test')
+        their_resource = OwnedResource.objects.create(description='another test', user=another_user)
+
+        my_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_resource)
+        my_second_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_second_resource)
+        their_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=their_resource)
+
+        my_twice_nested = OwnedResourceTwiceNestedOwnership.objects.create(description="test", parent=my_nested)
+        their_twice_nested = OwnedResourceTwiceNestedOwnership.objects.create(description="test", parent=their_nested)
+
+        response = self.client.get('/ownedresourcetwicenestedownerships/')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.data['ldp:contains']), 1)
+        ids = [r['@id'] for r in response.data['ldp:contains']]
+        self.assertIn(my_twice_nested.urlid, ids)
+        self.assertNotIn(their_twice_nested.urlid, ids)
+
+    def test_list_owned_resources_nested_does_not_exist(self):
+        self.setUpTempOwnerFieldForModel(OwnedResourceNestedOwnership, "parent__doesnotexist")
+
+        my_resource = OwnedResource.objects.create(description='test', user=self.user)
+        my_second_resource = OwnedResource.objects.create(description='test', user=self.user)
+        another_user = get_user_model().objects.create_user(username='test', email='test@test.com', password='test')
+        their_resource = OwnedResource.objects.create(description='another test', user=another_user)
+
+        my_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_resource)
+        my_second_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=my_second_resource)
+        their_nested = OwnedResourceNestedOwnership.objects.create(description="test", parent=their_resource)
+
+        self.assertRaises(ValueError, self.client.get, '/ownedresourcenestedownerships/')
